@@ -57,7 +57,7 @@ class queue:
                     event.dispatch(data['event'],data)
         if not self.__threadingStart:
             self.__threadingStart = True
-            threading.Thread(target=run,args=())
+            threading.Thread(target=run,args=()).start()
     def packetData(self,data):
         dataByte=bytes(data,encoding='utf-8')
         header="--#&content-length:{}&chunk:{}&index:{}&#--".format(len(dataByte),0,1)
@@ -68,9 +68,9 @@ class queue:
         if(len(matchs)==0):
             return None
         if matchs is not None:
-            start = reg.match(data).group()
-            contentLength=matchs[0]
-            contentIndex=int(start)+int(contentLength)
+            start = len(reg.match(data).group())
+            contentLength=int(matchs[0][0])
+            contentIndex=start+int(contentLength)
             if contentIndex>len(data):
                 contentIndex=len(data)
             content=data[start:contentIndex]
